package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.changx.util.CxXmlUtil;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;

import java.util.List;
import java.util.Map;

/**
 * @Description: 入院记录文档生成
 * @author: rengb
 * @time: 2020/3/5 15:47
 */
public class ChangxBeHospitalizedDocTrans extends ModelDocTrans {

    @Override
    public BeHospitalizedDoc extract(MedrecVo medrecVo) {
        String content = ((List<String>) medrecVo.getContent().get("content")).get(0);
        Map<String, String> sourceMap = CxXmlUtil.firstLevelNodeValue(content);
        Map<String, String> structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts);
        String specialCheck = structureMap.get("专科检查");
        if (StringUtil.isNotBlank(specialCheck)) {
            structureMap.put("专科体格检查", specialCheck);
        } else {
            String tgjc = concatSpecialCheck(sourceMap);
            if (StringUtil.isNotBlank(tgjc)) {
                structureMap.put("专科体格检查", tgjc);
            }
        }
        BeHospitalizedDoc beHospitalizedDoc = ModelDocGenerate.beHospitalizedDocGen(structureMap);
        beHospitalizedDoc.setText(content);
        beHospitalizedDoc.setPageData((Map) structureMap);
        return beHospitalizedDoc;
    }


    private String concatSpecialCheck(Map<String, String> sourceMap) {
        return concatString(sourceMap.get("一般情况")) +
                concatString(sourceMap.get("皮肤情况")) +
                concatString(sourceMap.get("淋巴")) +
                concatString(sourceMap.get("头部检查")) +
                concatString(sourceMap.get("颈部")) +
                concatString(sourceMap.get("胸部检查")) +
                concatString(sourceMap.get("肺部检查")) +
                concatString(sourceMap.get("心脏检查")) +
                concatString(sourceMap.get("血管")) +
                concatString(sourceMap.get("腹部检查")) +
                concatString(sourceMap.get("外生殖器")) +
                concatString(sourceMap.get("直肠肛门")) +
                concatString(sourceMap.get("四肢脊柱检查")) +
                concatString(sourceMap.get("神经系统检查")) +
                concatString(sourceMap.get("其他说明"));
    }

    private List<String> keyContrasts = Lists.newArrayList(
            "姓名++++患者姓名=姓名",
            "出生地++++出生地（住院）=出生地",
            "工作单位++++工作单位地址=工作单位",
            "婚姻状况++++婚姻=婚姻",
            "联系电话=电话",
            "供史者++++病史叙述者=病史陈述者",
            "++++病史叙述者=病史陈述者",
            "供史者++++供史者新=病史陈述者",
            "病史叙述者=病史陈述者",
            "婚育史:=婚育史",
            "外生殖器++++外生殖器文本框=",
            "户口地址=联系地址",
            "家庭住址++++现住址=现住址",
            "产次++++产=产次",
            "家长姓名++++家长=家长姓名",
            "职业++++首页职业新=职业"
    );

    private String concatString(String item) {
        if (StringUtil.isBlank(item)) {
            return "";
        } else {
            return item + "。";
        }
    }

}